@@ -25,7 +25,7 @@ impl AtomicOp for Op {
     }
 
     fn name(&self) -> String {
-        format!("RZ{}[{}]", self.a_mask, 2.0 * self.phase.arg())
+        format!("RZ{}({})", self.a_mask, 2.0 * self.phase.arg())
     }
 
     fn is_valid(&self) -> bool {
@@ -62,6 +62,6 @@ fn matrix_repr() {
     };
 
     let op: SingleOp = Op::new(0b1, ANGLE).into();
-    assert_eq!(op.name(), "RZ1[1.23456]");
+    assert_eq!(op.name(), "RZ1(1.23456)");
     assert_eq!(op.matrix(1), [[exp.conj(), O], [O, exp]]);
 }
