@@ -1,7 +1,7 @@
 use super::*;
 use crate::{
     math::{C, N, R},
-    operator::single::pauli::phi,
+    operator::single::rotate::rz,
 };
 
 pub fn qft(a_mask: N) -> MultiOp {
@@ -21,14 +21,12 @@ pub fn qft(a_mask: N) -> MultiOp {
             }
 
             for i in 0..(count - 1) {
-                res.append(&mut h::h(vec[i]).0);
-                res.push_back(
-                    phi(((i + 1)..count)
-                        .map(|j| (crate::math::PI * 0.5f64.powi((j - i) as i32), vec[j]))
-                        .collect())
-                    .c(vec[i])
-                    .unwrap(),
-                );
+                res.append(&mut h::h(vec[i]));
+                res.extend((1..(count - i)).map(|j| {
+                    rz(vec[i + j], crate::math::PI * 0.5f64.powi(j as i32))
+                        .and_then(|op| op.c(vec[i]))
+                        .unwrap()
+                }));
             }
 
             res.append(&mut h::h(vec[count - 1]).0);
